==> jc-1.4.0.tar.gz: polyglot/types/reflect/JLCInfo.h <==
// class polyglot.types.reflect.JLCInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b4794931ec0a1dff polyglot_types_reflect_JLCInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_JLCInfo_H_
#define _JC_polyglot_types_reflect_JLCInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_JLCInfo$sub_refs	_jc_polyglot_types_reflect_JLCInfo$sub_refs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$sub_nonrefs	_jc_polyglot_types_reflect_JLCInfo$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$refs	_jc_polyglot_types_reflect_JLCInfo$refs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$nonrefs	_jc_polyglot_types_reflect_JLCInfo$nonrefs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$object	_jc_polyglot_types_reflect_JLCInfo$object;

typedef const struct _jc_polyglot_types_reflect_JLCInfo$vmethods	_jc_polyglot_types_reflect_JLCInfo$vmethods;
typedef const struct _jc_polyglot_types_reflect_JLCInfo$vtable	_jc_polyglot_types_reflect_JLCInfo$vtable;
typedef const struct _jc_polyglot_types_reflect_JLCInfo$vtype	_jc_polyglot_types_reflect_JLCInfo$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_JLCInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_reflect_JLCInfo$object *);

// Virtual methods structure
struct _jc_polyglot_types_reflect_JLCInfo$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_JLCInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_JLCInfo$vmethods	polyglot_types_reflect_JLCInfo;
};

// Vtype
struct _jc_polyglot_types_reflect_JLCInfo$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_JLCInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_JLCInfo$sub_refs {
	struct _jc_java_lang_String$object	*compilerVersion;
	struct _jc_java_lang_String$object	*encodedClassType;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_JLCInfo$refs {
    _jc_polyglot_types_reflect_JLCInfo$sub_refs	polyglot_types_reflect_JLCInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_JLCInfo$sub_nonrefs {
	jlong	sourceLastModified;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_JLCInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_JLCInfo$sub_nonrefs	polyglot_types_reflect_JLCInfo;
};

// Object instance structure
struct _jc_polyglot_types_reflect_JLCInfo$object {
	_jc_polyglot_types_reflect_JLCInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_JLCInfo$vtype	*vtype;
	_jc_polyglot_types_reflect_JLCInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_JLCInfo$vtype _jc_polyglot_types_reflect_JLCInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_JLCInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_JLCInfo$class_object;

#endif	/* _JC_polyglot_types_reflect_JLCInfo_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/JLCInfo.h <==
// class polyglot.types.reflect.JLCInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b4794931ec0a1dff polyglot_types_reflect_JLCInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_JLCInfo_H_
#define _JC_polyglot_types_reflect_JLCInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_JLCInfo$sub_refs	_jc_polyglot_types_reflect_JLCInfo$sub_refs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$sub_nonrefs	_jc_polyglot_types_reflect_JLCInfo$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$refs	_jc_polyglot_types_reflect_JLCInfo$refs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$nonrefs	_jc_polyglot_types_reflect_JLCInfo$nonrefs;
typedef struct _jc_polyglot_types_reflect_JLCInfo$object	_jc_polyglot_types_reflect_JLCInfo$object;

typedef const struct _jc_polyglot_types_reflect_JLCInfo$vmethods	_jc_polyglot_types_reflect_JLCInfo$vmethods;
typedef const struct _jc_polyglot_types_reflect_JLCInfo$vtable	_jc_polyglot_types_reflect_JLCInfo$vtable;
typedef const struct _jc_polyglot_types_reflect_JLCInfo$vtype	_jc_polyglot_types_reflect_JLCInfo$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_JLCInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_reflect_JLCInfo$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_JLCInfo$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_JLCInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_JLCInfo$vmethods	polyglot_types_reflect_JLCInfo;
};

// Vtype
struct _jc_polyglot_types_reflect_JLCInfo$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_JLCInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_JLCInfo$sub_refs {
	struct _jc_java_lang_String$object	*compilerVersion;
	struct _jc_java_lang_String$object	*encodedClassType;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_JLCInfo$refs {
    _jc_polyglot_types_reflect_JLCInfo$sub_refs	polyglot_types_reflect_JLCInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_JLCInfo$sub_nonrefs {
	jlong	sourceLastModified;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_JLCInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_JLCInfo$sub_nonrefs	polyglot_types_reflect_JLCInfo;
};

// Object instance structure
struct _jc_polyglot_types_reflect_JLCInfo$object {
	_jc_polyglot_types_reflect_JLCInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_JLCInfo$vtype	*vtype;
	_jc_polyglot_types_reflect_JLCInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_JLCInfo$vtype _jc_polyglot_types_reflect_JLCInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_JLCInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_JLCInfo$class_object;

#endif	/* _JC_polyglot_types_reflect_JLCInfo_H_ */
